@@ -62,21 +62,18 @@ class RedditContentObject(object):
         json_dict).
 
         """
-        if info_url:
-            self._info_url = info_url
-        else:
-            self._info_url = reddit_session.config['info']
+        self._info_url = info_url or reddit_session.config['info']
         self.reddit_session = reddit_session
         self._underscore_names = underscore_names
-        self._populated = self._populate(json_dict, fetch)
+        self.has_fetched = self._populate(json_dict, fetch)
 
     def __eq__(self, other):
         return (isinstance(other, RedditContentObject) and
                 self.fullname == other.fullname)
 
     def __getattr__(self, attr):
-        if not self._populated:
-            self._populated = self._populate(None, True)
+        if not self.has_fetched:
+            self.has_fetched = self._populate(None, True)
             return getattr(self, attr)
         raise AttributeError('\'%s\' has no attribute \'%s\'' % (type(self),
                                                                  attr))
@@ -121,10 +118,7 @@ class RedditContentObject(object):
 
     def _populate(self, json_dict, fetch):
         if json_dict is None:
-            if fetch:
-                json_dict = self._get_json_dict()
-            else:
-                json_dict = {}
+            json_dict = self._get_json_dict() if fetch else {}
 
         # TODO: Remove this wikipagelisting hack
         if isinstance(json_dict, list):
@@ -427,6 +421,13 @@ class Voteable(RedditContentObject):
 
         Running this on an object with no existing vote has no adverse effects.
 
+        Note: votes must be cast by humans. That is, API clients proxying a
+        human's action one-for-one are OK, but bots deciding how to vote on
+        content or amplifying a human's vote are not. See the reddit rules for
+        more details on what constitutes vote cheating.
+
+        Source for note: http://www.reddit.com/dev/api#POST_api_vote
+
         :returns: The json response from the server.
 
         """
@@ -435,6 +436,13 @@ class Voteable(RedditContentObject):
     def downvote(self):
         """Downvote object. If there already is a vote, replace it.
 
+        Note: votes must be cast by humans. That is, API clients proxying a
+        human's action one-for-one are OK, but bots deciding how to vote on
+        content or amplifying a human's vote are not. See the reddit rules for
+        more details on what constitutes vote cheating.
+
+        Source for note: http://www.reddit.com/dev/api#POST_api_vote
+
         :returns: The json response from the server.
 
         """
@@ -443,6 +451,13 @@ class Voteable(RedditContentObject):
     def upvote(self):
         """Upvote object. If there already is a vote, replace it.
 
+        Note: votes must be cast by humans. That is, API clients proxying a
+        human's action one-for-one are OK, but bots deciding how to vote on
+        content or amplifying a human's vote are not. See the reddit rules for
+        more details on what constitutes vote cheating.
+
+        Source for note: http://www.reddit.com/dev/api#POST_api_vote
+
         :returns: The json response from the server.
 
         """
@@ -452,6 +467,13 @@ class Voteable(RedditContentObject):
     def vote(self, direction=0):
         """Vote for the given item in the direction specified.
 
+        Note: votes must be cast by humans. That is, API clients proxying a
+        human's action one-for-one are OK, but bots deciding how to vote on
+        content or amplifying a human's vote are not. See the reddit rules for
+        more details on what constitutes vote cheating.
+
+        Source for note: http://www.reddit.com/dev/api#POST_api_vote
+
         :returns: The json response from the server.
 
         """
@@ -606,8 +628,10 @@ class Redditor(Messageable, Refreshable):
 
     """A class representing the users of reddit."""
 
-    get_overview = _get_section('')
     get_comments = _get_section('comments')
+    get_disliked = _get_section('disliked')
+    get_liked = _get_section('liked')
+    get_overview = _get_section('')
     get_submitted = _get_section('submitted')
 
     def __init__(self, reddit_session, user_name=None, json_dict=None,
@@ -679,9 +703,7 @@ class LoggedInRedditor(Redditor):
 
     """A class representing a currently logged in Redditor."""
 
-    get_disliked = _get_section('disliked')
     get_hidden = _get_section('hidden')
-    get_liked = _get_section('liked')
     get_saved = _get_section('saved')
 
     def get_blocked(self):
@@ -918,6 +940,31 @@ class Submission(Editable, Hideable, Moderatable, Refreshable, Reportable,
         """
         return self.subreddit.set_flair(self, *args, **kwargs)
 
+    @restrict_access(scope='modposts')
+    def set_contest_mode(self, state=True):
+        """Set 'Contest Mode' for the comments of this submission.
+
+        Contest mode have the following effects.
+          * The comment thread will default to being sorted randomly.
+          * Replies to top-level comments will be hidden behind
+              "[show replies]" buttons.
+          * Scores will be hidden from non-moderators.
+          * Scores accessed through the API (mobile apps, bots) will be
+              obscured to "1" for non-moderators.
+
+        Source for effects: http://www.reddit.com/r/bestof2012/comments/159bww/
+                            introducing_contest_mode_a_tool_for_your_voting
+
+        :returns: The json response from the server.
+
+        """
+        # TODO: Whether a submission is in contest mode is not exposed via the
+        # API. Adding a test of this method is thus currently impossible.
+        # Add a test when it becomes possible.
+        url = self.reddit_session.config['contest_mode']
+        data = {'id': self.fullname, 'state': state}
+        return self.reddit_session.request_json(url, data=data)
+
     @property
     def short_link(self):
         """Return a short link to the submission.
@@ -942,6 +989,26 @@ class Submission(Editable, Hideable, Moderatable, Refreshable, Reportable,
         data = {'id': self.fullname, 'state': True}
         return self.reddit_session.request_json(url, data=data)
 
+    @restrict_access(scope='modposts')
+    def unset_contest_mode(self):
+        """Unset 'Contest Mode' for the comments of this submission.
+
+        Contest mode have the following effects.
+          * The comment thread will default to being sorted randomly.
+          * Replies to top-level comments will be hidden behind
+              "[show replies]" buttons.
+          * Scores will be hidden from non-moderators.
+          * Scores accessed through the API (mobile apps, bots) will be
+              obscured to "1" for non-moderators.
+
+        Source for effects: http://www.reddit.com/r/bestof2012/comments/159bww/
+                            introducing_contest_mode_a_tool_for_your_voting
+
+        :returns: The json response from the server.
+
+        """
+        return self.set_contest_mode(False)
+
     @restrict_access(scope='modposts')
     def unsticky(self):
         """Unsticky this post.
